@@ -32,7 +32,7 @@
         config.params = {graph_type: graph_type};
       }
 
-      return apiService.get('/api/vitrage/topology', config)
+      return apiService.get('/api/vitrage/topology/', config)
         .error(function () {
           toastService.add('error', gettext('Unable to fetch the Vitrage Topology service.'));
         });
